@@ -1,10 +1,11 @@
-from django.db.models import F
+from typing import Optional
 
 from celery.task import task
+from django.db.models import F
 
 
 @task(serializer="json")
-def execute_schedule_task(schedule_id):
+def execute_schedule_task(schedule_id: int) -> Optional[int]:
     from snitch.schedules.models import Schedule
 
     try:
@@ -16,7 +17,7 @@ def execute_schedule_task(schedule_id):
 
 
 @task(serializer="json")
-def clean_scheduled_tasks():
+def clean_scheduled_tasks() -> None:
     """Task to clean one shot periodic tasks. Note that this can be done better
     using the proper attributes for PeriodicTask.
     """
